@@ -57,7 +57,8 @@ build_time_vars = {'ABIFLAGS': '',
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed   -Wl,-z,now '
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  '
+                             '-Wl,-z,pack-relative-relocs -Wl,-z,now '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
@@ -1235,7 +1236,8 @@ build_time_vars = {'ABIFLAGS': '',
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed   -Wl,-z,now '
+ 'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,pack-relative-relocs '
+                    '-Wl,-z,now '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
@@ -1243,7 +1245,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-package-notes  -g  '
                     '-fno-semantic-interposition -flto -fuse-linker-plugin '
                     '-ffat-lto-objects -flto-partition=none -g -Wl,-z,relro '
-                    '-Wl,--as-needed   -Wl,-z,now '
+                    '-Wl,--as-needed  -Wl,-z,pack-relative-relocs -Wl,-z,now '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
@@ -1254,7 +1256,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed   -Wl,-z,now '
+ 'PY_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  '
+                      '-Wl,-z,pack-relative-relocs -Wl,-z,now '
                       '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                       '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                       '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
@@ -1262,13 +1265,14 @@ build_time_vars = {'ABIFLAGS': '',
                       '-specs=/usr/lib/rpm/redhat/redhat-package-notes  -g  '
                       '-fno-semantic-interposition -flto -fuse-linker-plugin '
                       '-ffat-lto-objects -flto-partition=none -g -Wl,-z,relro '
-                      '-Wl,--as-needed   -Wl,-z,now '
+                      '-Wl,--as-needed  -Wl,-z,pack-relative-relocs -Wl,-z,now '
                       '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                       '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                       '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                       '-Wl,--build-id=sha1 '
                       '-specs=/usr/lib/rpm/redhat/redhat-package-notes  -g',
- 'PY_LDFLAGS_NOLTO': '-fno-lto -Wl,-z,relro -Wl,--as-needed   -Wl,-z,now '
+ 'PY_LDFLAGS_NOLTO': '-fno-lto -Wl,-z,relro -Wl,--as-needed  '
+                     '-Wl,-z,pack-relative-relocs -Wl,-z,now '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld-errors '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
